@@ -1,4 +1,7 @@
 package Catalyst::Plugin::AutoCRUD::Controller::Root;
+BEGIN {
+  $Catalyst::Plugin::AutoCRUD::Controller::Root::VERSION = '1.110470';
+}
 
 use strict;
 use warnings FATAL => 'all';
@@ -19,10 +22,11 @@ sub base : Chained PathPart('autocrud') CaptureArgs(0) {
     my ($self, $c) = @_;
 
     $c->stash->{current_view} = 'AutoCRUD::TT';
-    $c->stash->{version} = 'CPAC v'
+    $c->stash->{cpac_version} = 'CPAC v'
         . $Catalyst::Plugin::AutoCRUD::VERSION;
-    $c->stash->{site} = 'default';
+    $c->stash->{cpac_site} = 'default';
     $c->stash->{template} = 'list.tt';
+    $c->stash->{cpac_meta} = {};
 }
 
 # =====================================================================
@@ -55,7 +59,7 @@ sub table : Chained('db') PathPart('') Args(1) {
 
 sub site : Chained('base') PathPart CaptureArgs(1) {
     my ($self, $c, $site) = @_;
-    $c->stash->{site} = $site;
+    $c->stash->{cpac_site} = $site;
 }
 
 sub no_schema : Chained('site') PathPart('') Args(0) {
@@ -65,7 +69,7 @@ sub no_schema : Chained('site') PathPart('') Args(0) {
 
 sub schema : Chained('site') PathPart CaptureArgs(1) {
     my ($self, $c, $db) = @_;
-    $c->stash->{db} = $db;
+    $c->stash->{cpac_db} = $db;
 }
 
 sub no_source : Chained('schema') PathPart('') Args(0) {
@@ -73,17 +77,19 @@ sub no_source : Chained('schema') PathPart('') Args(0) {
     $c->detach('err_message');
 }
 
+# we know both the schema and the source here
 sub source : Chained('schema') PathPart Args(1) {
     my ($self, $c) = @_;
     $c->forward('do_meta');
-    $c->stash->{title} = $c->stash->{lf}->{main}->{title} .' List';
+    $c->stash->{cpac_title} = $c->stash->{cpac_meta}->{main}->{title} .' List';
 
     # allow frontend override in non-default site (default will be full-fat)
-    $c->stash->{frontend} ||= $c->stash->{site_conf}->{frontend};
-    $c->forward('AutoCRUD::'. ucfirst $c->stash->{frontend})
-        if $c->controller('AutoCRUD::'. ucfirst $c->stash->{frontend});
+    $c->stash->{cpac_frontend} ||= $c->stash->{site_conf}->{frontend};
+    $c->forward('Controller::AutoCRUD::'. ucfirst $c->stash->{cpac_frontend})
+        if $c->controller('AutoCRUD::'. ucfirst $c->stash->{cpac_frontend});
 }
 
+# for AJAX calls
 sub call : Chained('schema') PathPart('source') CaptureArgs(1) {
     my ($self, $c) = @_;
     $c->forward('do_meta');
@@ -91,12 +97,21 @@ sub call : Chained('schema') PathPart('source') CaptureArgs(1) {
 
 # =====================================================================
 
+# we know both the schema and the source here
 sub do_meta : Private {
     my ($self, $c, $table) = @_;
-    $c->stash->{table} = $table;
+    $c->stash->{cpac_table} = $table;
+
+    my $db = $c->stash->{cpac_db};
+    my $site = $c->stash->{cpac_site};
+
+    $c->stash->{cpac_backend_store} =
+        $c->stash->{site_conf}->{$db}->{backend_store} ||
+        ('Model::AutoCRUD::Backend::'. ($c->stash->{site_conf}->{$db}->{backend} || 'DBIC'));
+    $c->stash->{cpac_backend_meta} =
+        $c->stash->{site_conf}->{$db}->{backend_meta} ||
+        ('Model::AutoCRUD::Metadata::'. ($c->stash->{site_conf}->{$db}->{backend} || 'DBIC'));
 
-    my $db = $c->stash->{db};
-    my $site = $c->stash->{site};
     $c->forward('build_site_config');
 
     # ACLs on the schema and source from site config
@@ -117,8 +132,8 @@ sub do_meta : Private {
         }
     }
 
-    $c->forward('AutoCRUD::Metadata');
-    $c->detach('err_message') if !defined $c->stash->{lf}->{model};
+    $c->stash->{cpac_meta} = $c->forward($c->stash->{cpac_backend_meta});
+    $c->detach('err_message') if !defined $c->stash->{cpac_meta}->{model};
 }
 
 sub verboden : Private {
@@ -128,43 +143,83 @@ sub verboden : Private {
     # detaches -> end
 }
 
+# when user has not selected a source, we don't know which backend to use
+sub _enumerate_metadata_backends {
+    my ($self, $c) = @_;
+    my $config = $c->config->{'Plugin::AutoCRUD'}->{sites}->{$c->stash->{cpac_site}};
+    my @backends = qw/Model::AutoCRUD::Metadata::DBIC/;
+
+    foreach my $s (sort keys %$config) {
+        next unless exists $config->{$s} and exists $config->{$s}->{backend_meta};
+        push @backends, $config->{$s}->{backend_meta};
+    }
+    $c->log->debug(join ':', 'Backends are', ' ', @backends) if $c->debug;
+    return @backends;
+}
+
+# we know only the schema or no schema, or there is a problem
 sub err_message : Private {
     my ($self, $c) = @_;
 
     $c->forward('build_site_config') if !exists $c->stash->{site_conf};
-    $c->forward('AutoCRUD::Metadata') if !defined $c->stash->{lf}->{db2path};;
-    $c->stash->{frontend} ||= $c->stash->{site_conf}->{frontend};
+
+    # forward to each metadata builder to provide db data
+    if (!defined $c->stash->{cpac_meta}->{db2path}) {
+        foreach my $backend ($self->_enumerate_metadata_backends($c)) {
+            $c->stash->{cpac_meta} = Catalyst::Utils::merge_hashes(
+                $c->stash->{cpac_meta}, $c->forward($backend));
+        }
+    }
+
+    # a fugly hack for back-compat - if there is only one schema running,
+    # then set that and re-dispatch to the metadata builder to set sources list
+    if (scalar keys %{$c->stash->{cpac_meta}->{dbpath2model}} == 1) {
+        my $db = [keys %{$c->stash->{cpac_meta}->{dbpath2model}}]->[0];
+        $c->stash->{cpac_db} = $db;
+        my $backend = (exists $c->stash->{site_conf}->{$db}->{backend_meta}
+            ? $c->stash->{site_conf}->{$db}->{backend_meta}
+            : 'Model::AutoCRUD::Metadata::DBIC'); # the default
+        $c->stash->{cpac_meta} = Catalyst::Utils::merge_hashes(
+            $c->stash->{cpac_meta}, $c->forward($backend));
+    }
+
+    $c->stash->{cpac_frontend} ||= $c->stash->{site_conf}->{frontend};
     $c->stash->{template} = 'tables.tt';
 }
 
 # build site config for filtering the frontend
 sub build_site_config : Private {
     my ($self, $c) = @_;
-    my $site = $self->_site_conf_cache->{$c->stash->{site}} ||= {};
+    my $site = $self->_site_conf_cache->{$c->stash->{cpac_site}} ||= {};
+    my $cpac = {};
 
     # if we have it cached
     if ($site->{__built}) {
         $c->stash->{site_conf} = $site;
         $c->log->debug(sprintf "autocrud: retreived cached config for site [%s]",
-            $c->stash->{site}) if $c->debug;
+            $c->stash->{cpac_site}) if $c->debug;
         return;
     }
 
     # first, prime our structure of schema and source aliases
-    # get stash of db path parts
-    my $lf = $c->forward(qw/AutoCRUD::Metadata build_db_info/);
-    foreach my $db (keys %{$lf->{dbpath2model}}) {
-        $site->{$db} ||= {};
-        # get stash of table path parts
-        $c->forward(qw/AutoCRUD::Metadata build_table_info_for_db/, [$lf, $db]);
-        foreach my $table (keys %{$lf->{path2model}->{$db}}) {
-            $site->{$db}->{$table} ||= {};
+    foreach my $backend ($self->_enumerate_metadata_backends($c)) {
+        # get stash of db path parts
+        my $meta = $c->forward($backend, 'build_db_info');
+        foreach my $db (keys %{$meta->{dbpath2model}}) {
+            $site->{$db} ||= {};
+            # get stash of table path parts
+            $c->forward($backend, 'build_table_info_for_db', [$meta, $db]);
+            foreach my $table (keys %{$meta->{path2model}->{$db}}) {
+                $site->{$db}->{$table} ||= {};
+            }
         }
+        # store this for setting override on *_allowed later
+        $cpac = Catalyst::Utils::merge_hashes( $cpac, $meta );
     }
 
     # load whatever the user set in their site config
     $site = Catalyst::Utils::merge_hashes(
-        ($c->config->{'Plugin::AutoCRUD'}->{sites}->{$c->stash->{site}} || {}),
+        ($c->config->{'Plugin::AutoCRUD'}->{sites}->{$c->stash->{cpac_site}} || {}),
         $site);
 
     my %defaults = (
@@ -172,8 +227,10 @@ sub build_site_config : Private {
         create_allowed => 'yes',
         update_allowed => 'yes',
         delete_allowed => 'yes',
+        dumpmeta_allowed => 'no',
         hidden => 'no',
     );
+    $defaults{dumpmeta_allowed} = 'yes' if $ENV{AUTOCRUD_TESTING};
 
     # merge defaults into user prefs
     $site = Catalyst::Utils::merge_hashes (\%defaults, $site);
@@ -191,6 +248,13 @@ sub build_site_config : Private {
                     map {($_ => $site->{$sc}->{$_})} keys %defaults
                 }, $site->{$sc}->{$so});
 
+            # override *_allowed if the source is read only
+            if (not $cpac->{editable}->{$sc}->{$so}) {
+                $site->{$sc}->{$so}->{create_allowed} = 'no';
+                $site->{$sc}->{$so}->{update_allowed} = 'no';
+                $site->{$sc}->{$so}->{delete_allowed} = 'no';
+            }
+
             # back-compat work for list_returns
             if (exists $site->{$sc}->{$so}->{list_returns} and
                     (!exists $site->{$sc}->{$so}->{headings} and !exists $site->{$sc}->{$so}->{columns})) {
@@ -228,10 +292,10 @@ sub build_site_config : Private {
 
     $site->{__built} = 1;
     $c->stash->{site_conf} = $site;
-    $self->_site_conf_cache->{$c->stash->{site}} = $site;
+    $self->_site_conf_cache->{$c->stash->{cpac_site}} = $site;
 
     $c->log->debug(sprintf "autocrud: cached the config for site [%s]",
-            $c->stash->{site}) if $c->debug;
+            $c->stash->{cpac_site}) if $c->debug;
 }
 
 sub helloworld : Chained('base') Args(0) {
@@ -241,7 +305,7 @@ sub helloworld : Chained('base') Args(0) {
 
 sub end : ActionClass('RenderView') {
     my ($self, $c) = @_;
-    my $frontend = $c->stash->{frontend} || 'full-fat';
+    my $frontend = $c->stash->{cpac_frontend} || 'full-fat';
 
     my $tt_path = $c->config->{'Plugin::AutoCRUD'}->{tt_path};
     $tt_path = (defined $tt_path ? (ref $tt_path eq '' ? [$tt_path] : $tt_path ) : [] );
